[Mesa-dev] [PATCH] mesa: Make sure the buffer exists in _mesa_lookup_bufferobj_err

Fredrik Höglund fredrik at kde.org
Thu Mar 19 15:48:05 PDT 2015


Generate GL_INVALID_OPERATION and return NULL when the buffer object
hasn't been created.  All callers expect this.

Cc: Laura Ekstrand <laura at jlekstrand.net>
---
 src/mesa/main/bufferobj.c | 11 +++++++----
 1 file changed, 7 insertions(+), 4 deletions(-)

diff --git a/src/mesa/main/bufferobj.c b/src/mesa/main/bufferobj.c
index 78d3d78..41455f3 100644
--- a/src/mesa/main/bufferobj.c
+++ b/src/mesa/main/bufferobj.c
@@ -1003,8 +1003,8 @@ _mesa_lookup_bufferobj_locked(struct gl_context *ctx, GLuint buffer)
 
 /**
  * A convenience function for direct state access functions that throws
  * GL_INVALID_OPERATION if buffer is not the name of a buffer object in the
  * hash table.
  */
 struct gl_buffer_object *
 _mesa_lookup_bufferobj_err(struct gl_context *ctx, GLuint buffer,
@@ -1013,9 +1013,12 @@ _mesa_lookup_bufferobj_err(struct gl_context *ctx, GLuint buffer,
    struct gl_buffer_object *bufObj;
 
    bufObj = _mesa_lookup_bufferobj(ctx, buffer);
-   if (!bufObj)
+   if (!bufObj || bufObj == &DummyBufferObject) {
       _mesa_error(ctx, GL_INVALID_OPERATION,
-                  "%s(non-generated buffer name %u)", caller, buffer);
+                  "%s(%u is not the name of an existing buffer object)",
+                  caller, buffer);
+      return NULL;
+   }
 
    return bufObj;
 }
@@ -1003,8 +1003,8 @@ _mesa_lookup_bufferobj_locked(struct gl_context *ctx, GLuint buffer)
 /**
  * A convenience function for direct state access functions that throws
- * GL_INVALID_OPERATION if buffer is not the name of a buffer object in the
- * hash table.
+ * GL_INVALID_OPERATION if buffer is not the name of an existing
+ * buffer object.
  */
 struct gl_buffer_object *
-- 
2.1.4



More information about the mesa-dev mailing list